<?php

namespace wpbuddy\rich_snippets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly


/**
 * Class Admin_Plugins.
 *
 * Does things on the plugins screen.
 *
 * @package wpbuddy\rich_snippets
 *
 * @since   2.13.1
 */
final class Admin_Plugins_Controller {

	/**
	 * Magic method for setting upt the class.
	 *
	 * Disallow external instances.
	 *
	 * @since 2.13.1
	 */
	public function __construct() {
		add_filter( 'plugin_action_links_' . plugin_basename( rich_snippets()->get_plugin_file() ),
			[
				$this,
				'action_links'
			]
		);

		add_action( 'admin_enqueue_scripts', [ $this, 'scripts' ] );
	}


	/**
	 * Modifies the plugin action links.
	 *
	 * @param array $actions
	 *
	 * @return array
	 * @since 2.13.1
	 *
	 */
	public function action_links( $actions ) {

		$actions['uninstall'] = sprintf(
			'<a href="%1$s" aria-label="%2$s">%3$s</a>',
			esc_url( add_query_arg( [
				'page'  => 'rich-snippets-uninstall',
				'_wpnonce' => wp_create_nonce( 'rich-snippets-uninstall' )
			], admin_url( 'index.php' ) ) ),
			__( 'Uninstall the SNIP plugin', 'rich-snippets-schema' ),
			__( 'Uninstall', 'rich-snippets-schema' )
		);

		return $actions;
	}


	/**
	 * Enqueues plugin page styles and scripts.
	 *
	 * @since 2.13.1
	 */
	public function scripts() {
		wp_register_style(
			'wpb-rs-admin-plugins',
			plugins_url( 'css/admin-plugins.css', rich_snippets()->get_plugin_file() ),
			[],
			filemtime( plugin_dir_path( rich_snippets()->get_plugin_file() ) . 'css/admin-plugins.css' )
		);

		wp_enqueue_style( 'wpb-rs-admin-plugins' );
	}
}
